==> coinbase_exchange-0.0.1.tar.gz: lib/src/lib/coinbase_enums.dart <==
enum CoinbaseLevel {
  one,
  two,
  three,
}

extension Value on CoinbaseLevel {
  int value() {
    if (this == CoinbaseLevel.one) return 1;
    if (this == CoinbaseLevel.two) return 2;
    else return 3;
  }
}

enum CoinbaseGranularity {
  oneMinute,
  fiveMinutes,
  fifteenMinutes,
  oneHour,
  sixHours,
  oneDay,
}

extension Seconds on CoinbaseGranularity {
  int seconds() {
    if (this == CoinbaseGranularity.oneMinute) return 60;
    if (this == CoinbaseGranularity.fiveMinutes) return 300;
    if (this == CoinbaseGranularity.fifteenMinutes) return 900;
    if (this == CoinbaseGranularity.oneHour) return 3600;
    if (this == CoinbaseGranularity.sixHours) return 21600;
    else return 86400;
  }
}

enum CoinbaseSide {
  buy,
  sell,
}

extension Side on CoinbaseSide {
  String side() {
    if (this == CoinbaseSide.buy) return 'buy';
    else return 'sell';
  }
}

enum CoinbaseOrderType {
  limit,
  market,
  stop,
}

enum Action {
  subscribe,
  unsubscribe,
}

extension OrderType on CoinbaseOrderType {
  String orderType() {
    if (this == CoinbaseOrderType.limit) return 'limit';
    if (this == CoinbaseOrderType.market) return 'market';
    else return 'stop';
  }
}

enum CoinbaseChannel {
  heartBeat,
  status,
  ticker,
  level2,
  user,
  matches,
  full,
}

extension Channel on CoinbaseChannel {
  String channel() {
    if (this == CoinbaseChannel.heartBeat) return 'heartbeat';
    if (this == CoinbaseChannel.status) return 'status';
    if (this == CoinbaseChannel.ticker) return 'ticker';
    if (this == CoinbaseChannel.level2) return 'level2';
    if (this == CoinbaseChannel.user) return 'user';
    if (this == CoinbaseChannel.matches) return 'matches';
    else return 'full';
  }
}

enum CoinbaseReason {
  filled,
  canceled,
}

extension Reason on CoinbaseReason {
  String reason() {
    return this == CoinbaseReason.filled ? 'filled' : 'canceled';
  }
}

enum CoinbaseTransferType {
  withdrawal,
  deposit,
}

extension TransferType on CoinbaseTransferType {
  String transferType() {
    if (this == CoinbaseTransferType.withdrawal) return 'withdrawal';
    else return 'deposit';
  }
}

==> coinbase_exchange-0.0.5.tar.gz: lib/src/lib/coinbase_enums.dart <==
enum CoinbaseLevel {
  one,
  two,
  three,
}

extension Value on CoinbaseLevel {
  int value() {
    if (this == CoinbaseLevel.one) return 1;
    if (this == CoinbaseLevel.two)
      return 2;
    else
      return 3;
  }
}

enum CoinbaseGranularity {
  oneMinute,
  fiveMinutes,
  fifteenMinutes,
  oneHour,
  sixHours,
  oneDay,
}

extension Seconds on CoinbaseGranularity {
  int seconds() {
    if (this == CoinbaseGranularity.oneMinute) return 60;
    if (this == CoinbaseGranularity.fiveMinutes) return 300;
    if (this == CoinbaseGranularity.fifteenMinutes) return 900;
    if (this == CoinbaseGranularity.oneHour) return 3600;
    if (this == CoinbaseGranularity.sixHours)
      return 21600;
    else
      return 86400;
  }
}

enum CoinbaseSide {
  buy,
  sell,
}

extension Side on CoinbaseSide {
  String side() {
    if (this == CoinbaseSide.buy)
      return 'buy';
    else
      return 'sell';
  }
}

enum CoinbaseOrderType {
  limit,
  market,
  stop,
}

enum Action {
  subscribe,
  unsubscribe,
}

extension OrderType on CoinbaseOrderType {
  String orderType() {
    if (this == CoinbaseOrderType.limit) return 'limit';
    if (this == CoinbaseOrderType.market)
      return 'market';
    else
      return 'stop';
  }
}

enum CoinbaseChannel {
  heartBeat,
  status,
  ticker,
  level2,
  user,
  matches,
  full,
}

extension Channel on CoinbaseChannel {
  String channel() {
    if (this == CoinbaseChannel.heartBeat) return 'heartbeat';
    if (this == CoinbaseChannel.status) return 'status';
    if (this == CoinbaseChannel.ticker) return 'ticker';
    if (this == CoinbaseChannel.level2) return 'level2';
    if (this == CoinbaseChannel.user) return 'user';
    if (this == CoinbaseChannel.matches)
      return 'matches';
    else
      return 'full';
  }
}

enum CoinbaseReason {
  filled,
  canceled,
}

extension Reason on CoinbaseReason {
  String reason() {
    return this == CoinbaseReason.filled ? 'filled' : 'canceled';
  }
}

enum CoinbaseTransferType {
  withdrawal,
  deposit,
}

extension TransferType on CoinbaseTransferType {
  String transferType() {
    if (this == CoinbaseTransferType.withdrawal)
      return 'withdrawal';
    else
      return 'deposit';
  }
}
